==> pur-api-1.2.3.33-yybpc-20250723.153014-1-sources.jar: com/elitesland/pur/dto/gr/PurGrDetailRpcDTO.java <==
package com.elitesland.pur.dto.gr;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

@Data
@ApiModel(description = "采购收货单明细")
public class PurGrDetailRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("明细ID")
    private Long id;

    @ApiModelProperty("商品id")
    private Long itemId;

    @ApiModelProperty("入库批次")
    private String inLotNo;

    @ApiModelProperty("发货数量")
    private BigDecimal deliveryQty;

    @ApiModelProperty("入库数量")
    private BigDecimal inQty;

    @ApiModelProperty("订货数量")
    private BigDecimal qty;

    @ApiModelProperty("单位")
    private String uom;

    @ApiModelProperty("基本单位")
    private String uom2;

    @ApiModelProperty("单位转换率")
    private BigDecimal uomRatio;

    @ApiModelProperty("小数位数")
    private Integer places;

    @ApiModelProperty("库存状态")
    private String limit1;

    @ApiModelProperty("可退数量")
    private BigDecimal canRtnQty;

    @ApiModelProperty("关联明细id")
    private Long relateDocDid;

    @ApiModelProperty("关联明细id2")
    private Long relateDoc2Did;

    @ApiModelProperty("行类型")
    private String lineType;

    @ApiModelProperty("储值账户金额")
    private BigDecimal storedAmt;

    @ApiModelProperty("信用账户金额")
    private BigDecimal creditAmt;

    @ApiModelProperty("返利账户金额")
    private BigDecimal rebateAmt;

    @ApiModelProperty("储值账户累计金额")
    private BigDecimal storedReturnAddAmt;

    @ApiModelProperty("返利账户累计金额")
    private BigDecimal rebateReturnAddAmt;

    @ApiModelProperty("信用账户累计金额")
    private BigDecimal creditReturnAddAmt;
}

==> pur-api-1.2.3.37-yybpc-20250726.074100-1-sources.jar: com/elitesland/pur/dto/gr/PurGrDetailRpcDTO.java <==
package com.elitesland.pur.dto.gr;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

@Data
@ApiModel(description = "采购收货单明细")
public class PurGrDetailRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("明细ID")
    private Long id;

    @ApiModelProperty("商品id")
    private Long itemId;

    @ApiModelProperty("入库批次")
    private String inLotNo;

    @ApiModelProperty("发货数量")
    private BigDecimal deliveryQty;

    @ApiModelProperty("入库数量")
    private BigDecimal inQty;

    @ApiModelProperty("订货数量")
    private BigDecimal qty;

    @ApiModelProperty("单位")
    private String uom;

    @ApiModelProperty("基本单位")
    private String uom2;

    @ApiModelProperty("单位转换率")
    private BigDecimal uomRatio;

    @ApiModelProperty("小数位数")
    private Integer places;

    @ApiModelProperty("含税总价（包含项目服务费）")
    private BigDecimal totalPrice;

    @ApiModelProperty("库存状态")
    private String limit1;

    @ApiModelProperty("含税单价")
    private BigDecimal price;

    @ApiModelProperty("可退数量")
    private BigDecimal canRtnQty;

    @ApiModelProperty("关联明细id")
    private Long relateDocDid;

    @ApiModelProperty("关联明细id2")
    private Long relateDoc2Did;

    @ApiModelProperty("行类型")
    private String lineType;

    @ApiModelProperty("储值账户金额")
    private BigDecimal storedAmt;

    @ApiModelProperty("信用账户金额")
    private BigDecimal creditAmt;

    @ApiModelProperty("返利账户金额")
    private BigDecimal rebateAmt;

    @ApiModelProperty("储值账户累计金额")
    private BigDecimal storedReturnAddAmt;

    @ApiModelProperty("返利账户累计金额")
    private BigDecimal rebateReturnAddAmt;

    @ApiModelProperty("信用账户累计金额")
    private BigDecimal creditReturnAddAmt;
}
